@@ -13,9 +13,9 @@ $(function() {
   var matchtab = function() {
     var url = document.location.toString();
     if (url.match('#/')) {
-      $('.nav-tabs a[href=#'+url.split('#/')[1]+']').tab('show');
+      $('.nav-tabs.nav-tabs-auto a[href=#'+url.split('#/')[1]+']').tab('show');
     } else if (url.match('#')) {
-      $('.nav-tabs a[href=#'+url.split('#')[1]+']').tab('show');
+      $('.nav-tabs.nav-tabs-auto a[href=#'+url.split('#')[1]+']').tab('show');
     }
   };
 
@@ -24,12 +24,12 @@ $(function() {
   // Load correct tab when the page loads
   matchtab();
   // Change hash for tab click
-  $('.nav-tabs a').on('shown', function (e) {
+  $('.nav-tabs.nav-tabs-auto a').on('shown', function (e) {
     window.location.hash = '#/' + e.target.hash.slice(1);
   });
   var url = document.location.toString();
   if (!url.match('#')) {
     // Activate the first tab if none are active
-    $('.nav-tabs a').filter(':first').tab('show');
+    $('.nav-tabs.nav-tabs-auto a').filter(':first').tab('show');
   }
 });
